class one:
<<<<<<< HEAD
 def addition(self, a, b):
  return a+b

 def subtraction(self, a,b):
=======
 def addition(a, b):
  return a+b

 def subtraction(a,b):
>>>>>>> 8162bbab90facba2d49697037af78414bd4ada39
  return a-b
